@@ -60,7 +60,7 @@ class TestPartner(unittest.TestCase):
         self.partner.start()
 
     def test_start_to(self):
-        self.partner.start_to('0.0.0.0')
+        self.partner.start_to('0.0.0.0', '0.0.0.0', 0, 0)
 
     def test_stop(self):
         self.partner.stop()
@@ -68,5 +68,6 @@ class TestPartner(unittest.TestCase):
     def test_wait_as_b_send_completion(self):
         self.partner.wait_as_b_send_completion()
 
+
 if __name__ == '__main__':
     unittest.main()
